TransitionToImage class

Inheritance

Constructors

TransitionToImage({Key? key, required ImageProvider<Object> image, double? width, double? height, BorderRadius? borderRadius, Color? color, BlendMode? blendMode, BoxFit fit = BoxFit.contain, Alignment alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, bool matchTextDirection = false, bool invertColors = false, ImageFilter? imageFilter, Widget placeholder = const Icon(Icons.clear), PlaceHolderBuilder? placeholderBuilder, Duration duration = const Duration(milliseconds: 300), Tween<Object?>? tween, Curve curve = Curves.easeInOut, TransitionType transitionType = TransitionType.fade, Widget loadingWidget = const Center(child: const CircularProgressIndicator()), LoadingWidgetBuilder? loadingWidgetBuilder, bool enableRefresh = false, bool longPressForceRefresh = false, bool disableMemoryCache = false, bool disableMemoryCacheIfFailed = false, VoidCallback? loadedCallback, VoidCallback? loadFailedCallback, bool forceRebuildWidget = false, bool printError = false})
const

Properties

alignment → Alignment
How to align the image within its bounds.
final
blendMode → BlendMode?
Used to combine color with this image.
final
borderRadius → BorderRadius?
The border radius of the rounded corners.
final
color → Color?
If non-null, this color is blended with each image pixel using colorBlendMode.
final
curve → Curve
The curve of the fade-out animation for the result.
final
disableMemoryCache → bool
If set to enable, the image provider will be evicted from ImageCache.
final
disableMemoryCacheIfFailed → bool
If set to enable, the image provider will be evicted from ImageCache if the image failed to load.
final
duration → Duration
The duration of the fade-out animation for the result.
final
enableRefresh → bool
Enable manually refreshing for network issues.
final
fit → BoxFit
How to inscribe the image into the space allocated during layout.
final
forceRebuildWidget → bool
If set to enable, the loadedCallback or loadFailedCallback will fire again.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
If non-null, require the image to have this height.
final
image → ImageProvider<Object>
The target image that is displayed.
final
imageFilter → ImageFilter?
final
invertColors → bool
Whether the colors of the image are inverted when drawn.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadedCallback → VoidCallback?
The callback will fire when the image loaded.
final
loadFailedCallback → VoidCallback?
The callback will fire when the image failed to load.
final
loadingWidget → Widget
Widget displayed when the target image is loading.
final
loadingWidgetBuilder → LoadingWidgetBuilder?
Widget builder (with loading progress) displayed when the target image is loading.
final
longPressForceRefresh → bool
force long press to refetch image.
final
matchTextDirection → bool
Whether to paint the image in the direction of the TextDirection.
final
placeholder → Widget
Widget displayed while the target image failed to load.
final
placeholderBuilder → PlaceHolderBuilder?
Widget builder (with reload function) displayed while the target image failed to load.
final
printError → bool
Print error.
final
repeat → ImageRepeat
How to paint any portions of the layout bounds not covered by the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionType → TransitionType
The transition type of the fade-out animation for the result.
final
tween → Tween<Object?>?
The tween of the fade-out animation for the result.
final
width → double?
If non-null, require the image to have this width.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TransitionToImageState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited